@@ -38,6 +38,24 @@ class ConfigDebugRequests(Config):
     )
 
 
+class ConfigDownload(Config):
+    """
+    Configure details about the download process
+    """
+    download_as_collecting = ParamCreator.create_bool(
+        help_string="Do you want download while collecting the urls?",
+        default=False,
+    )
+    download = ParamCreator.create_bool(
+        help_string="really download or just print the urls?",
+        default=True,
+    )
+    folder = ParamCreator.create_existing_folder(
+        help_string="where to save the data to?",
+        default=".",
+    )
+
+
 class ConfigCookiesSource(Config):
     """
         Configure where to get cookies from
@@ -75,10 +93,6 @@ class ConfigSiteId(Config):
             https://vk.com/id[user_id]
             http://www.mamba.ru/mb[user_id]""",
     )
-    start = ParamCreator.create_int(
-        help_string="start number for image names",
-        default=0,
-    )
 
 
 class ConfigPornhubSearch(Config):
@@ -124,16 +138,6 @@ class ConfigPornhubSearch(Config):
     )
 
 
-class ConfigPornhubDownload(Config):
-    """
-    Configuration for pornhub download
-    """
-    folder = ParamCreator.create_existing_folder(
-        help_string="where to save the data to?",
-        default="/home/mark/links/pornhub_dl",
-    )
-
-
 class ConfigYoutubeDl(Config):
     """
     Configuration to download a single url
@@ -141,7 +145,12 @@ class ConfigYoutubeDl(Config):
     url = ParamCreator.create_str(
         help_string="the URL to download",
     )
-    folder = ParamCreator.create_existing_folder(
-        help_string="where to save the data to?",
-        default="/home/mark/links/youtube_dl",
+
+
+class ConfigPornhubUrl(Config):
+    """
+    Parameters for what pornstar to download
+    """
+    url = ParamCreator.create_str(
+        help_string="url to download (e.g. model/lily)"
     )
